@@ -3,7 +3,7 @@ BEGIN {
   $POE::Component::IRC::Plugin::ImageMirror::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Plugin::ImageMirror::VERSION = '0.11';
+  $POE::Component::IRC::Plugin::ImageMirror::VERSION = '0.12';
 }
 
 use strict;
@@ -304,6 +304,13 @@ POE::Component::IRC::Plugin::ImageMirror - A PoCo-IRC plugin which uploads selec
 
 =head1 SYNOPSIS
 
+To quickly get an IRC bot with this plugin up and running, you can use
+L<App::Pocoirc|App::Pocoirc>:
+
+ $ pocoirc -s irc.perl.org -j '#bots' -p ImageMirror
+
+Or use it in your code:
+
  use POE::Component::IRC::Plugin::ImageMirror;
 
  # mirror all images from 4chan.org
